==> phoenix_widgets-1.7.1.tar.gz: lib/phoenix_webview.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_back_button.dart';
import 'package:phoenix_widgets/phoenix_title.dart';
import 'package:webview_flutter/webview_flutter.dart';

class PhoenixWebview extends StatefulWidget {
  const PhoenixWebview({
    Key? key,
    required this.url,
    required this.title
  }) : super(key: key);

  final String url;
  final String title;

  @override
  _PhoenixWebviewState createState() => _PhoenixWebviewState();
}

class _PhoenixWebviewState extends State<PhoenixWebview> {
  bool _isLoading = true;
  final Completer<WebViewController> _controller =
      Completer<WebViewController>();

  @override
  void initState() {
    super.initState();
    if (Platform.isAndroid) WebView.platform = SurfaceAndroidWebView();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
      Timer(const Duration(seconds: 10), () {
        if (mounted) {
          setState(() {
            _isLoading = false;
          });
        }
      });
    });
  }

  Future<bool> _onBackPressed() async {
    WebViewController controller = await _controller.future;
    bool canNavigate = await controller.canGoBack();
    if (canNavigate) {
      controller.goBack();
      return Future.value(false);
    } else {
      await controller.clearCache();
      Navigator.of(context).pop();
      return Future.value(true);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        title: PhoenixTitle(title: widget.title),
        leading: PhoenixBackButton(
          callback: _onBackPressed,
        ),
      ),
      body: WillPopScope(
        onWillPop: _onBackPressed,
        child: Stack(
          children: [
            Positioned.fill(
                child: WebView(
              initialUrl: widget.url,
              javascriptMode: JavascriptMode.unrestricted,
              onWebViewCreated: (controller) {
                _controller.complete(controller);
              },
              onPageFinished: (str) {
                setState(() {
                  _isLoading = false;
                });
              },
            )),
            _isLoading
                ? const Positioned.fill(
                    child: Center(
                    child: SizedBox(
                      width: 50.0,
                      height: 50.0,
                      child: CircularProgressIndicator(
                        strokeWidth: 1.5,
                        valueColor: AlwaysStoppedAnimation(Color(0xFF67C1BF)),
                      ),
                    ),
                  ))
                : Container()
          ],
        ),
      ),
    );
  }
}

==> phoenix_widgets-1.7.4.tar.gz: lib/phoenix_webview.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_back_button.dart';
import 'package:phoenix_widgets/phoenix_title.dart';
import 'package:webview_flutter/webview_flutter.dart';

class PhoenixWebview extends StatefulWidget {
  const PhoenixWebview({Key? key, required this.url, required this.title})
      : super(key: key);

  final String url;
  final String title;

  @override
  _PhoenixWebviewState createState() => _PhoenixWebviewState();
}

class _PhoenixWebviewState extends State<PhoenixWebview> {
  bool _isLoading = true;
  final Completer<WebViewController> _controller =
      Completer<WebViewController>();

  @override
  void initState() {
    super.initState();
    if (Platform.isAndroid) WebView.platform = SurfaceAndroidWebView();
    WidgetsBinding.instance.addPostFrameCallback((timeStamp) {
      Timer(const Duration(seconds: 10), () {
        if (mounted) {
          setState(() {
            _isLoading = false;
          });
        }
      });
    });
  }

  Future<bool> _onBackPressed() async {
    WebViewController controller = await _controller.future;
    bool canNavigate = await controller.canGoBack();
    if (canNavigate) {
      controller.goBack();
      return Future.value(false);
    } else {
      await controller.clearCache();
      Navigator.of(context).pop();
      return Future.value(true);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        title: PhoenixTitle(title: widget.title),
        leading: PhoenixBackButton(
          callback: _onBackPressed,
        ),
      ),
      body: WillPopScope(
        onWillPop: _onBackPressed,
        child: Stack(
          children: [
            Positioned.fill(
                child: WebView(
              initialUrl: widget.url,
              javascriptMode: JavascriptMode.unrestricted,
              onWebViewCreated: (controller) {
                _controller.complete(controller);
              },
              onPageFinished: (str) {
                setState(() {
                  _isLoading = false;
                });
              },
            )),
            _isLoading
                ? const Positioned.fill(
                    child: Center(
                    child: SizedBox(
                      width: 50.0,
                      height: 50.0,
                      child: CircularProgressIndicator(
                        strokeWidth: 1.5,
                        valueColor: AlwaysStoppedAnimation(Color(0xFF67C1BF)),
                      ),
                    ),
                  ))
                : Container()
          ],
        ),
      ),
    );
  }
}
